Technical guide
===============

.. toctree::
    :maxdepth: 2
    :caption: Introduction

    overview_development

    cli

    extensions

.. toctree::
    :maxdepth: 2
    :caption: ASReview file

    example_api_asreview_file

.. autosummary::
    :toctree: reference/
    :caption: API Reference
    :recursive:

    asreview


Indices and tables
------------------

- :ref:`genindex`
- :ref:`modindex`
